==> kie-wb-common-7.20.0.Final-project-sources.tar.gz: kie-wb-common-7.20.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-bpmn/kie-wb-common-stunner-bpmn-api/src/main/java/org/kie/workbench/common/stunner/bpmn/documentation/model/element/ElementTotal.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.bpmn.documentation.model.element;

import java.util.List;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL, name = "Object")
public class ElementTotal {

    private Element[] elements;
    private int quantity;
    private String type;//category
    private String typeIcon;//category icon

    private ElementTotal() {

    }

    @JsOverlay
    public static final ElementTotal create(List<Element> elements, String type, String typeIcon) {
        final ElementTotal instance = new ElementTotal();
        instance.quantity = elements.size();
        instance.elements = elements.toArray(new Element[elements.size()]);
        instance.type = type;
        instance.typeIcon = typeIcon;
        return instance;
    }

    @JsOverlay
    public final String getType() {
        return type;
    }
}

==> kie-wb-common-7.31.0.Final-project-sources.tar.gz: kie-wb-common-7.31.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-bpmn/kie-wb-common-stunner-bpmn-api/src/main/java/org/kie/workbench/common/stunner/bpmn/documentation/model/element/ElementTotal.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.bpmn.documentation.model.element;

import java.util.List;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL, name = "Object")
public class ElementTotal {

    private Element[] elements;
    private int quantity;
    private String type;//category
    private String typeIcon;//category icon

    private ElementTotal() {

    }

    @JsOverlay
    public static final ElementTotal create(List<Element> elements, String type, String typeIcon) {
        final ElementTotal instance = new ElementTotal();
        instance.quantity = elements.size();
        instance.elements = elements.toArray(new Element[elements.size()]);
        instance.type = type;
        instance.typeIcon = typeIcon;
        return instance;
    }

    @JsOverlay
    public final String getType() {
        return type;
    }

    @JsOverlay
    public final Element[] getElements() {
        return elements;
    }

    @JsOverlay
    public final int getQuantity() {
        return quantity;
    }

    @JsOverlay
    public final String getTypeIcon() {
        return typeIcon;
    }
}
